import os
from resources.accounts import Accounts

default_endpoint = os.environ["ONVO_API_ENDPOINT"]
default_api_key = os.environ["ONVO_API_KEY"]


class Onvo:
    def __init__(self, endpoint=default_endpoint, api_key=default_api_key):
        self.endpoint = endpoint
        self.api_key = api_key

        params = [endpoint, api_key]

        self.accounts = Accounts.new(*params)
        # self.teams = Teams.new(*params)
        # self.embed_users = EmbedUsers.new(*params)
        # self.datasources = Datasources.new(*params)
        # self.automations = Automations.new(*params)
        # self.dashboards = Dashboards.new(*params)



import requests
import json


class Resource:
    def __init__(self, endpoint, api_key):
        self.endpoint = endpoint
        self.headers = {"x-api-key": api_key, "Content-Type": "application/json"}

    def handle_response(self, response):
        try:
            return json.loads(response.body)
        except ValueError:
            return response.body

    def get_url(self, subdirectory):
        return "{base_url}{subdirectory}".format(
            base_url=self.endpoint, subdirectory=subdirectory
        )

    def get(self, subdirectory):
        url = self.get_url(subdirectory)
        response = requests.get(url)
        return self.handle_response(response)
